Module: GovKit::OpenStates
- Defined in:
- lib/gov_kit/open_states.rb
Overview
Ruby module for interacting with the Open States Project API
See http://openstates.sunlightlabs.com/api/
Most find and search methods:
- call HTTParty::ClassMethods#get
- which returns an HTTParty::Response object
- which is passed to GovKit::Resource#parse
- which uses the response to populate a Resource
Defined Under Namespace
Classes: Action, Address, Bill, Committee, Legislator, Role, Source, Sponsor, State, Version, Vote
Constant Summary collapse
- ROLE_MEMBER =
"member"- ROLE_COMMITTEE_MEMBER =
"committee member"- CHAMBER_UPPER =
"upper"- CHAMBER_LOWER =
"lower"